<?php
/*
Plugin Name: Advanced Featured Post Widget
Plugin URI: http://wasistlos.waldemarstoffel.com/plugins-fur-wordpress/advanced-featured-post-widget
Description: The Advanced Featured Post Widget is yet another plugin to make your blog a bit more newspaper-like. Just by choosing a post from the dropdown menu, you can put it in the 'featured' area and display thumbnail, headline, excerpt or all three of them (if available) in the fully customizable widget. It just has more options than the the Featured Post Widget.
Version: 2.9
Author: Waldemar Stoffel
Author URI: http://www.waldemarstoffel.com
License: GPL3
Text Domain: advanced-fpw
*/

/*  Copyright 2011 - 2013  Waldemar Stoffel  (email : w-stoffel@gmx.net)

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/


/* Stop direct call */

if(preg_match('#' . basename(__FILE__) . '#', $_SERVER['PHP_SELF'])) die('Sorry, you don\'t have direct access to this page.');

define( 'AFPW_PATH', plugin_dir_path(__FILE__) );

if (!class_exists('A5_Image')) require_once AFPW_PATH.'class-lib/A5_ImageClass.php';
if (!class_exists('A5_Excerpt')) require_once AFPW_PATH.'class-lib/A5_ExcerptClass.php';
if (!class_exists('Advanced_Featured_Post_Widget')) require_once AFPW_PATH.'class-lib/AFPW_WidgetClass.php';
if (!class_exists('A5_FormField')) require_once AFPW_PATH.'class-lib/A5_FormFieldClass.php';
if (!function_exists('a5_textarea')) require_once AFPW_PATH.'includes/A5_field-functions.php';

class Advanced_FPW {
	
	const language_file = 'advanced-fpw';
	
	private static $options;
	
	function __construct() {
		
		self::$options = get_option('afpw_options');
		
		// import laguage files
	
		load_plugin_textdomain(self::language_file, false , basename(dirname(__FILE__)).'/languages');

		add_action('admin_enqueue_scripts', array($this, 'afpw_js_sheet'));
		add_filter('plugin_row_meta', array($this, 'afpw_register_links'), 10, 2);
		add_filter('plugin_action_links', array($this, 'afpw_plugin_action_links'), 10, 2);
		add_action('admin_init', array($this, 'afpw_init'));
		register_activation_hook(  __FILE__, array($this, 'install_afpw') );
		register_deactivation_hook(  __FILE__, array($this, 'unset_afpw') );
		add_action('admin_menu', array($this, 'afpw_admin_menu'));
		add_action('init', array($this, 'afpw_add_rewrite'));
		add_action('template_redirect', array($this, 'afpw_css_template'));
		add_action ('wp_enqueue_scripts', array($this, 'afpw_css'));
		
	}

	/* attach JavaScript file for textarea resizing */
	
	function afpw_js_sheet($hook) {
		
		if ($hook != 'settings_page_advanced-fpw-settings' && $hook != 'widgets.php') return;
		
		wp_register_script('ta-expander-script', plugins_url('ta-expander.js', __FILE__), array('jquery'), '3.0', true);
		wp_enqueue_script('ta-expander-script');
	
	}
	
	//Additional links on the plugin page
	
	function afpw_register_links($links, $file) {
		
		$base = plugin_basename(__FILE__);
		
		if ($file == $base) :
			
			$links[] = '<a href="http://wordpress.org/extend/plugins/advanced-featured-post-widget/faq/" target="_blank">'.__('FAQ', self::language_file).'</a>';
			$links[] = '<a href="https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=4P2ACVGPHY7WU" target="_blank">'.__('Donate', self::language_file).'</a>';
		
		endif;
		
		return $links;
	
	}
	
	function afpw_plugin_action_links( $links, $file ) {
		
		$base = plugin_basename(__FILE__);
		
		if ($file == $base) array_unshift($links, '<a href="'.admin_url( 'options-general.php?page=advanced-fpw-settings' ).'">'.__('Settings', self::language_file).'</a>');
	
		return $links;
	
	}
	
	// init
	
	function afpw_init() {
		
		register_setting( 'afpw_options', 'afpw_options', array($this, 'afpw_validate') );
		
		add_settings_section('afpw_settings', __('Styling of the links', self::language_file), array($this, 'afpw_display_section'), 'afpw_styles');
		
		add_settings_field('afpw_link_style', __('Link style:', self::language_file), array($this, 'afpw_link_field'), 'afpw_styles', 'afpw_settings');
		
		add_settings_field('afpw_hover_style', __('Hover style:', self::language_file), array($this, 'afpw_hover_field'), 'afpw_styles', 'afpw_settings');
		
		add_settings_field('afpw_resize', false, array($this, 'afpw_resize_field'), 'afpw_styles', 'afpw_settings');
	
	}
	
	function afpw_display_section() {
		
		echo '<p>'.__('Just put some css code here.', self::language_file).'</p>';
	
	}
	
	function afpw_link_field() {
		
		a5_textarea('link', 'afpw_options[link]', @self::$options['link'], false, array('cols' => 35, 'rows' => 3));
		
	}
	
	function afpw_hover_field() {
		
		a5_textarea('hover', 'afpw_options[hover]', @self::$options['hover'], false, array('cols' => 35, 'rows' => 3));
		
	}
	
	function afpw_resize_field() {
		
		a5_resize_textarea(array('link', 'hover'), true);
		
	}
	
	// Creating default options on activation
	
	static function install_afpw() {
		
		$default = array(
			'tags' => array(),
			'sizes' => array()
		);
		
		add_option('afpw_options', $default);
		
	}	
	
	// Cleaning on deactivation
	
	static function unset_afpw() {
		
		delete_option('afpw_options');
		
	}
	
	// Installing options page
	
	function afpw_admin_menu() {
		
		add_options_page('Advanced FP '.__('Settings', self::language_file), '<img alt="" src="'.plugins_url('advanced-featured-post-widget/img/a5-icon-11.png').'"> Advanced Featured Post Widget', 'administrator', 'advanced-fpw-settings', array($this, 'advanced_fpw_options_page'));
		
	}
	
	// Calling the options page
	
	function advanced_fpw_options_page() {
		
		?>
		
		<div class="wrap">
    <a href="<?php _e('http://wasistlos.waldemarstoffel.com/plugins-fur-wordpress/advanced-featured-post-widget', self::language_file); ?>"><div id="a5-logo" class="icon32" style="background: url('<?php echo plugins_url('advanced-featured-post-widget/img/a5-icon-34.png');?>');"></div></a>
		<h2><?php echo 'Advanced Featured Post Widget '.__('Settings', self::language_file); ?></h2>
		<?php settings_errors(); ?>
		<?php _e('Style the links of the widget. If you leave this empty, your theme will style the hyperlinks.', self::language_file); ?>
		<p><?php _e('Just input something like,', self::language_file); ?>
		<p><strong>font-weight: bold;<br />
		color: #0000ff;<br />
		text-decoration: underline;    
		</strong></p>
		<?php _e('to get fat, blue, underlined links.', self::language_file); ?></p>
		<p><strong><?php _e('You most probably have to use &#34;!important&#34; at the end of each line, to make it work.', self::language_file); ?></strong></p>
		
		<form action="options.php" method="post">
		
		<?php
		
		settings_fields('afpw_options');
		do_settings_sections('afpw_styles');
		submit_button();
		
		?>
		
		</form></div>
		<?php
	
	}
	
	function afpw_validate($input) {
		
		self::$options = get_option('afpw_options');
		
		self::$options['link']=trim($input['link']);
		self::$options['hover']=trim($input['hover']);
		
		return self::$options;
	
	}
	
	function afpw_add_rewrite() {
		
		   global $wp;
		   $wp->add_query_var('afpwfile');
		   
	}
	
	function afpw_css_template() {
		   if (get_query_var('afpwfile') == 'css') {
				   
				   header('Content-type: text/css');
				   echo $this->afpw_write_css();
				   
				   exit;
		   }
	}
	
	function afpw_css () {
		
		if (!empty (self::$options['link']) || !empty (self::$options['hover'])) :		
			
			$afpw_css_file=get_bloginfo('url').'/?afpwfile=css';
			
			wp_register_style('advanced-fpw', $afpw_css_file, false, '2.9', 'all');
			wp_enqueue_style('advanced-fpw');
				
		endif;
		
	}
	
	// writing css file
		
	function afpw_write_css() {
		
		$eol = "\r\n";
		
		$css_text='@charset "UTF-8";'.$eol.'/* CSS Document */'.$eol.$eol;
		
		if (!empty(self::$options['link'])) {
				   
				   $afpw_link=str_replace(array("\r\n", "\n", "\r"), ' ', self::$options['link']);
				   $css_text.='div[id^="advanced_featured_post_widget"].widget_advanced_featured_post_widget a {'.$afpw_link.'}'.$eol;
				   
		}
				   
		if (!empty(self::$options['hover'])) {
				   
				   $afpw_hover=str_replace(array("\r\n", "\n", "\r"), ' ', self::$options['hover']);
				   $css_text.='div[id^="advanced_featured_post_widget"].widget_advanced_featured_post_widget a:hover {'.$afpw_hover.'}';
				   
		}
		
		return $css_text;
		
	}

}

$advanced_fpw = new Advanced_FPW;

?>